@@ -14,7 +14,6 @@ import logging
 import os
 import pprint
 import sys
-import time
 
 import attr
 import psutil
@@ -29,6 +28,7 @@ from saltfactories.exceptions import FactoryNotStarted
 from saltfactories.exceptions import FactoryTimeout
 from saltfactories.utils import ports
 from saltfactories.utils import running_username
+from saltfactories.utils import time
 from saltfactories.utils.processes import Popen
 from saltfactories.utils.processes import ProcessResult
 from saltfactories.utils.processes import ShellResult
@@ -385,7 +385,7 @@ class DaemonFactory(SubprocessFactoryBase):
     def _format_callback(self, callback, args, kwargs):
         callback_str = "{}(".format(callback.__name__)
         if args:
-            callback_str += ", ".join(args)
+            callback_str += ", ".join([repr(arg) for arg in args])
         if kwargs:
             callback_str += ", ".join(["{}={!r}".format(k, v) for (k, v) in kwargs.items()])
         callback_str += ")"
@@ -399,16 +399,6 @@ class DaemonFactory(SubprocessFactoryBase):
             log.warning("%s is already running.", self)
             return True
         process_running = False
-        for callback, args, kwargs in self.before_start_callbacks:
-            try:
-                callback(*args, **kwargs)
-            except Exception as exc:  # pylint: disable=broad-except
-                log.info(
-                    "Exception raised when running %s: %s",
-                    self._format_callback(callback, args, kwargs),
-                    exc,
-                    exc_info=True,
-                )
         start_time = time.time()
         start_attempts = max_start_attempts or self.max_start_attempts
         current_attempt = 0
@@ -420,6 +410,16 @@ class DaemonFactory(SubprocessFactoryBase):
             if current_attempt > start_attempts:
                 break
             log.info("Starting %s. Attempt: %d of %d", self, current_attempt, start_attempts)
+            for callback, args, kwargs in self.before_start_callbacks:
+                try:
+                    callback(*args, **kwargs)
+                except Exception as exc:  # pylint: disable=broad-except
+                    log.info(
+                        "Exception raised when running %s: %s",
+                        self._format_callback(callback, args, kwargs),
+                        exc,
+                        exc_info=True,
+                    )
             current_start_time = time.time()
             start_running_timeout = current_start_time + (start_timeout or self.start_timeout)
             if current_attempt > 1 and self.extra_cli_arguments_after_first_start_failure:
@@ -554,14 +554,18 @@ class DaemonFactory(SubprocessFactoryBase):
         # we have set on listen_ports, terminate those processes.
         found_processes = []
         for process in psutil.process_iter(["connections"]):
-            for connection in process.connections():
-                if connection.status != psutil.CONN_LISTEN:
-                    # We only care about listening services
-                    continue
-                if connection.laddr.port in self.check_ports:
-                    found_processes.append(process)
-                    # We already found one connection, no need to check the others
-                    break
+            try:
+                for connection in process.connections():
+                    if connection.status != psutil.CONN_LISTEN:
+                        # We only care about listening services
+                        continue
+                    if connection.laddr.port in self.check_ports:
+                        found_processes.append(process)
+                        # We already found one connection, no need to check the others
+                        break
+            except psutil.AccessDenied:
+                # We've been denied access to this process connections. Carry on.
+                continue
         if found_processes:
             log.debug(
                 "The following processes were found listening on ports %s: %s",
